@@ -1,7 +1,4 @@
-{-# LANGUAGE CPP #-}
-#ifdef __GLASGOW_HASKELL__
 {-# LANGUAGE MagicHash #-}
-#endif
 
 {-# OPTIONS_HADDOCK hide #-}
 
@@ -13,7 +10,7 @@
 --
 -- The Package Versioning Policy __does not apply__.
 --
--- This contents of this module may change __in any way whatsoever__
+-- The contents of this module may change __in any way whatsoever__
 -- and __without any warning__ between minor versions of this package.
 --
 -- Authors importing this module are expected to track development
@@ -21,15 +18,9 @@
 
 module Data.Dependent.Map.PtrEquality (ptrEq, hetPtrEq) where
 
-#ifdef __GLASGOW_HASKELL__
-import GHC.Exts ( reallyUnsafePtrEquality# )
-import Unsafe.Coerce ( unsafeCoerce )
-#if __GLASGOW_HASKELL__ < 707
-import GHC.Exts ( (==#) )
-#else
-import GHC.Exts ( isTrue# )
-#endif
-#endif
+import Unsafe.Coerce (unsafeCoerce)
+import GHC.Exts (isTrue#, reallyUnsafePtrEquality#)
+
 
 -- | Checks if two pointers are equal. Yes means yes;
 -- no means maybe. The values should be forced to at least
@@ -42,20 +33,8 @@ ptrEq :: a -> a -> Bool
 -- reliable results.
 hetPtrEq :: a -> b -> Bool
 
-#ifdef __GLASGOW_HASKELL__
-#if __GLASGOW_HASKELL__ < 707
-ptrEq x y = reallyUnsafePtrEquality# x y ==# 1#
-hetPtrEq x y = unsafeCoerce reallyUnsafePtrEquality# x y ==# 1#
-#else
 ptrEq x y = isTrue# (reallyUnsafePtrEquality# x y)
 hetPtrEq x y = isTrue# (unsafeCoerce reallyUnsafePtrEquality# x y)
-#endif
-
-#else
--- Not GHC
-ptrEq _ _ = False
-hetPtrEq _ _ = False
-#endif
 
 {-# INLINE ptrEq #-}
 {-# INLINE hetPtrEq #-}
